@@ -224,9 +224,11 @@ def get_value_from_array(data_arr_input, low_li, up_li):
 def main():
     parser = argparse.ArgumentParser(prog='vinset',
                                      description='VINSET package.')
-    parser.add_argument('--version', action='version', version='2.0.4'),
+    parser.add_argument('--version', action='version', version='2.0.6'),
     parser.add_argument("-i", dest="input_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="input mp4 file", metavar="filename.mp4")
+    parser.add_argument("-d", dest="input_data_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
+                        help="input csv data file", metavar="filename.csv")
     parser.add_argument("-o", dest="output_filename", required=True, type=argparse.FileType('w'), default=sys.stdout,
                         help="output mp4 file", metavar="filename.mp4")
     parser.add_argument("-c", dest="config_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
@@ -234,6 +236,7 @@ def main():
 
     args = parser.parse_args()
     input_file = args.input_filename.name
+    csv_data = args.input_data_filename.name
     output_file = args.output_filename.name
     config_file = args.config_filename.name
 
@@ -263,7 +266,6 @@ def main():
     if draw_able and data:
         axes_array = data["axes"]
         series_array = data["series"]
-        csv_data = data["csv_data"]
         display_able = str_to_bool(str(data["display"]))
 
         input_video = cv2.VideoCapture(input_file)
@@ -305,10 +307,12 @@ def main():
                     else:
                         data_arr = get_data_array(csv_data, t_data, y_data)
                     series_data_array = []
-                    time_interval_for_data = round(1000 / (axes_pos_w / t_w), 2)
+                    time_interval_for_data = round(1000 / (axes_pos_w / t_w), 4)
                     number_of_time_interval = math.ceil(max_video_length / time_interval_for_data)
                     lower_range = 0
                     upper_range = round((lower_range + time_interval_for_data), 2)
+                    width_check = int(t_w) * 1000
+                    box_data_array = []
                     for i in range(1, (number_of_time_interval + 1), 1):
                         raw_data_array = []
                         # input_data = None
@@ -316,13 +320,22 @@ def main():
                             if lower_range <= data[0] < upper_range:
                                 raw_data_array.append(data)
                         input_data = get_value_from_array(raw_data_array, lower_range, upper_range)
-                        raw_data_array.clear()
-                        series_data_array.append([upper_range, input_data])
+                        box_data_array.append(input_data)
+                        if max_video_length <= width_check:
+                            if i == (number_of_time_interval - 1):
+                                another_box_array = box_data_array[:]
+                                series_data_array.append([int(width_check), another_box_array])
+                        else:
+                            if upper_range >= width_check:
+                                another_box_array = box_data_array[:]
+                                series_data_array.append([int(width_check), another_box_array])
+                                box_data_array.clear()
+                                width_check += (int(t_w) * 1000)
                         lower_range = upper_range
                         upper_range = round((upper_range + time_interval_for_data), 2)
                     draw_data_array.append([series_name, display_type, series_data_array])
 
-                elif str(display_type).lower() == "refresh":
+                elif str(display_type).lower() == "static":
                     if info_filter:
                         data_arr = get_data_array(csv_data, t_data, y_data, info_filter, filter_by)
                     else:
@@ -501,56 +514,87 @@ def main():
                     parent_index = get_position_of_parent(search_str, axes_array)
                     axes_info = axes_array[parent_index]
                     if show_type == "pen" and parent_index is not None:
-                        pass
-                        # ax_pos = axes_info["position"]
-                        # ax_x = ax_pos["x"]
-                        # ax_y = ax_pos["y"]
-                        # ax_w = ax_pos["width"]
-                        # ax_h = ax_pos["height"]
-                        # zero_line_start_x = ax_x
-                        # zero_line_y_scale = int(number_to_scale(lower_limit, upper_limit, ax_h, 0))
-                        # zero_line_y = int(ax_y + ax_h - zero_line_y_scale)
-                        # zero_line_end_x = ax_x + ax_w
-                        # time_in_pixel_value = round((t_width / ax_w), 2)
-                        # start_x = ax_x
-                        # start_y = ax_y + int(ax_h / 2)
-                        # # first_step = 0
-                        # value_to_draw = False
-                        # step = 1
+                        ax_pos = axes_info["position"]
+                        ax_x = ax_pos["x"]
+                        ax_y = ax_pos["y"]
+                        ax_w = ax_pos["width"]
+                        ax_h = ax_pos["height"]
+                        zero_line_start_x = ax_x
+                        zero_line_y_scale = int(number_to_scale(lower_limit, upper_limit, ax_h, 0))
+                        zero_line_y = int(ax_y + ax_h - zero_line_y_scale)
+                        zero_line_end_x = ax_x + ax_w
+                        time_in_pixel_value = round((t_width / ax_w), 20)
+                        time_interval_for_data = round(1 / (ax_w / t_width), 20)
+                        start_x = ax_x
+                        start_y = 0
+                        value_to_draw = False
+                        display_count = int(check_timer / (t_width * 1000))
+                        # total_display_count = int(max_video_length / (t_width * 1000))
                         # end_x = 0
                         # end_y = 0
-                        # len_array = len(display_arr)
-                        # if len_array > 0:
-                        # for ind, number in enumerate(display_arr):
-                        #     if zero_display:
-                        #         cv2.line(clone_frame, (zero_line_start_x, zero_line_y),
-                        #                  (zero_line_end_x, zero_line_y),
-                        #                  line_color_array[i], zero_line_thick)
-                        #     if math.isnan(number[1]):
-                        #         start_x = 0
-                        #         start_y = 0
-                        #         value_to_draw = False
-                        #         pass
-                        #     else:
-                        #         if not value_to_draw:
-                        #             scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, number[1])
-                        #             scaled_step = int(number[0] / time_in_pixel_value)
-                        #             start_x = ax_x + scaled_step
-                        #             start_y = int(ax_y + ax_h - scaled_num)
-                        #             value_to_draw = True
-                        #         else:
-                        #             scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, number[1])
-                        #             scaled_step = int(number[0] / time_in_pixel_value)
-                        #             end_x = ax_x + scaled_step
-                        #             end_y = int(ax_y + ax_h - scaled_num)
-                        #             cv2.line(clone_frame, (start_x, start_y), (end_x, end_y),
-                        #                      line_color_array[i], line_thickness, cv2.LINE_AA)
-                        #             if need_to_draw_pointer and ind == len_array - 1:
-                        #                 cv2.circle(clone_frame, (end_x, end_y), pointer_radius, pointer_color, -1)
-                        #             start_x = end_x
-                        #             start_y = end_y
+                        final_display_arr = display_arr[display_count][1]
+                        draw_after = False
+                        pointer_x = 0
+                        pointer_y = 0
+                        check_timer_input = check_timer - (display_count * t_width * 1000)
+                        drawable_limit = ax_x + int((check_timer_input / (time_interval_for_data * 1000)))
+                        # pen_draw = False
+                        no_first_value = False
 
-                    elif show_type == "refresh" and parent_index is not None:
+                        if len(final_display_arr) > 0:
+                            for ind, num in enumerate(final_display_arr):
+                                if zero_display:
+                                    cv2.line(clone_frame, (zero_line_start_x, zero_line_y),
+                                             (zero_line_end_x, zero_line_y),
+                                             line_color_array[i], zero_line_thick)
+                                if type(num[1]) == str:
+                                    if ind == 0:
+                                        no_first_value = True
+
+                                elif math.isnan(num[1]):
+                                    value_to_draw = False
+
+                                else:
+                                    if not value_to_draw:
+                                        if no_first_value:
+                                            scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, num[1])
+                                            start_x = ax_x
+                                            start_y = int(ax_y + ax_h - scaled_num)
+                                            value_to_draw = True
+                                            no_first_value = False
+                                        else:
+                                            scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, num[1])
+                                            # scaled_step = int(round(((num[0] / 1000) / time_in_pixel_value), 0))
+                                            scaled_step = math.ceil((num[0] / 1000) / time_in_pixel_value)
+                                            start_x = ax_x + scaled_step - (display_count * ax_w)
+                                            start_y = int(ax_y + ax_h - scaled_num)
+                                            value_to_draw = True
+                                    else:
+                                        if start_x >= drawable_limit:
+                                            pen_draw = False
+                                        else:
+                                            pen_draw = True
+                                        if pen_draw:
+                                            scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, num[1])
+                                            # scaled_step = int(round(((num[0] / 1000) / time_in_pixel_value), 0))
+                                            scaled_step = math.ceil((num[0] / 1000) / time_in_pixel_value)
+                                            end_x = ax_x + scaled_step - (display_count * ax_w)
+                                            end_y = int(ax_y + ax_h - scaled_num)
+                                            cv2.line(clone_frame, (start_x, start_y), (end_x, end_y),
+                                                     line_color_array[i], line_thickness, cv2.LINE_AA)
+                                            if need_to_draw_pointer and round(num[0], 2) >= round(check_timer, 2):
+                                                draw_after = True
+                                                pointer_x = end_x
+                                                pointer_y = end_y
+                                            start_x = end_x
+                                            start_y = end_y
+
+                            if draw_after:
+                                # draw_after = False
+                                cv2.circle(clone_frame,
+                                           (pointer_x, pointer_y), pointer_radius, pointer_color, -1)
+
+                    elif show_type == "static" and parent_index is not None:
                         ax_pos = axes_info["position"]
                         ax_x = ax_pos["x"]
                         ax_y = ax_pos["y"]
@@ -570,6 +614,9 @@ def main():
                         # end_x = 0
                         # end_y = 0
                         final_display_arr = display_arr[display_count][1]
+                        draw_after = False
+                        pointer_x = 0
+                        pointer_y = 0
 
                         if len(final_display_arr) > 0:
                             for ind, num in enumerate(final_display_arr):
@@ -577,6 +624,7 @@ def main():
                                     cv2.line(clone_frame, (zero_line_start_x, zero_line_y),
                                              (zero_line_end_x, zero_line_y),
                                              line_color_array[i], zero_line_thick)
+
                                 if type(num[1]) == str:
                                     pass
 
@@ -590,6 +638,7 @@ def main():
                                         start_x = ax_x + scaled_step - (display_count * ax_w)
                                         start_y = int(ax_y + ax_h - scaled_num)
                                         value_to_draw = True
+
                                     else:
                                         scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, num[1])
                                         scaled_step = int(round(((num[0] / 1000) / time_in_pixel_value), 0))
@@ -601,11 +650,17 @@ def main():
                                         cv2.line(clone_frame, (start_x, start_y), (end_x, end_y),
                                                  line_color_array[i], line_thickness, cv2.LINE_AA)
                                         if need_to_draw_pointer and round(num[0], 2) == round(check_timer, 2):
-                                            cv2.circle(clone_frame,
-                                                       (end_x, end_y), pointer_radius, pointer_color, -1)
+                                            draw_after = True
+                                            pointer_x = end_x
+                                            pointer_y = end_y
                                         start_x = end_x
                                         start_y = end_y
 
+                            if draw_after:
+                                # draw_after = False
+                                cv2.circle(clone_frame,
+                                           (pointer_x, pointer_y), pointer_radius, pointer_color, -1)
+
                 for info in series_array:
                     search_string = info["parent_axes"]
                     parent_index = get_position_of_parent(search_string, axes_array)
